Module head

Module head 

Heads track where the first free byte in an arena is.

Structs

SingleThreadedHead
ThreadSafeHead

Traits

Head
The head is the pointer that gets bumped in a bump allocator. It tracks of how many bytes have been marked as in-use.