pub trait Head {
// Required methods
fn num_bytes_used(&self) -> usize;
fn bump(&self, inc: usize);
fn set(&self, v: usize);
}Expand description
The head is the pointer that gets bumped in a bump allocator. It tracks of how many bytes have been marked as in-use.