BumpAllocator

Struct BumpAllocator 

pub struct BumpAllocator<'a, M: BumpAllocatorArena = &'a [u8], H: Head = SingleThreadedHead> { /* private fields */ }
A generic bump allocator.

The bump allocator works on memory M, tracking where the remaining free memory starts using head H.

Implementations

Source

impl<'a> BumpAllocator<'a>

pub const fn with_slice(arena: &'a [u8]) -> SliceBumpAllocator<'a>

Source

impl<'a> BumpAllocator<'a, &'a [u8], ThreadSafeHead>

pub const fn with_slice(arena: &'a [u8]) -> ThreadsafeSliceBumpAllocator<'a>

Source

impl<'a, M: BumpAllocatorArena, H: Head + Default> BumpAllocator<'a, M, H>

pub const fn new(memory: M, head: H) -> Self

pub unsafe fn reset(&self)

pub fn arena(&self) -> &dyn BumpAllocatorArena