pub type SliceBumpAllocator<'a> = BumpAllocator<'a, &'a [u8], SingleThreadedHead>;Expand description
A BumpAllocator that uses the given byte slice as the arena.
Aliased Type
pub struct SliceBumpAllocator<'a> { /* private fields */ }pub type SliceBumpAllocator<'a> = BumpAllocator<'a, &'a [u8], SingleThreadedHead>;A BumpAllocator that uses the given byte slice as the arena.
pub struct SliceBumpAllocator<'a> { /* private fields */ }