pub type ThreadsafeSliceBumpAllocator<'a> = BumpAllocator<'a, &'a [u8], ThreadSafeHead>;Expand description
A BumpAllocator that uses the given slice as the arena.
Aliased Type
pub struct ThreadsafeSliceBumpAllocator<'a> { /* private fields */ }pub type ThreadsafeSliceBumpAllocator<'a> = BumpAllocator<'a, &'a [u8], ThreadSafeHead>;A BumpAllocator that uses the given slice as the arena.
pub struct ThreadsafeSliceBumpAllocator<'a> { /* private fields */ }