Module head
silly_
alloc
0.1.0
Module head
Module Items
Structs
Traits
In silly_
alloc::
bump
silly_alloc
::
bump
Module
head
Heads track where the first free byte in an arena is.
Structs

Single
Threaded
Head
Thread
Safe
Head
Traits

Head
The head is the pointer that gets bumped in a bump allocator. It tracks of how many bytes have been marked as in-use.